@@ -1,10 +1,25 @@
 from .base import GrooveBase
+
 from .spline import SplineGroove
 from .generic_elongation import GenericElongationGroove
+
 from .boxes import BoxGroove, ConstrictedBoxGroove, UpsetBoxGroove, ConstrictedUpsetBoxGroove
+
 from .diamonds import DiamondGroove, SquareGroove, GothicGroove
-from .ovals import CircularOvalGroove, FlatOvalGroove, SwedishOvalGroove, ConstrictedSwedishOvalGroove, \
-    Oval3RadiiGroove, Oval3RadiiFlankedGroove, UpsetOvalGroove, ConstrictedCircularOvalGroove
+
+from .ovals import (
+    CircularOvalGroove,
+    FlatOvalGroove,
+    SwedishOvalGroove,
+    ConstrictedSwedishOvalGroove,
+    Oval3RadiiGroove,
+    Oval3RadiiFlankedGroove,
+    UpsetOvalGroove,
+    ConstrictedCircularOvalGroove
+)
+
 from .rounds import RoundGroove, FalseRoundGroove
+
 from .flat import FlatGroove
+
 from .hexagonal import HexagonalGroove
