@@ -28,11 +28,6 @@ def width_3fold(self: Profile):
         return (self.cross_section.bounds[3] - self.cross_section.centroid.y) * 2
 
 
-@Profile.length
-def length(self: Profile):
-    return 0
-
-
 @Profile.equivalent_height
 def equivalent_height(self: Profile):
     return np.sqrt(self.cross_section.area * self.height / self.width)
@@ -56,3 +51,15 @@ def surface_temperature(self: Profile):
 @Profile.core_temperature
 def core_temperature(self: Profile):
     return self.temperature
+
+
+@Profile.heat_penetration_number
+def heat_penetration_number(self: Profile):
+    if hasattr(self, "thermal_conductivity") and hasattr(self, "density") and hasattr(self, "thermal_capacity"):
+        return np.sqrt(self.thermal_conductivity * self.density * self.thermal_capacity)
+
+
+@Profile.thermal_diffusivity
+def thermal_diffusivity(self: Profile):
+    if hasattr(self, "thermal_conductivity") and hasattr(self, "density") and hasattr(self, "thermal_capacity"):
+        return self.thermal_conductivity / (self.density * self.thermal_capacity)
