@@ -1,5 +1,6 @@
 import math
-from typing import Optional, Tuple, Iterable, Union, Set, Callable
+from typing import Optional, Union, Callable
+from collections.abc import Iterable, Collection, Set
 
 import numpy as np
 from shapely.affinity import translate, rotate
@@ -79,13 +80,19 @@ class Profile(HookHost):
     density = Hook[float]()
     """Mean density (specific weight) of the profile material."""
 
-    material = Hook[Union[str, Iterable[str]]]()
+    material = Hook[Union[str, Set[str]]]()
     """String or sequence of strings classifying the material of the profile.
     Can be used by material databases to retrieve respective data."""
 
     grain_size = Hook[float]()
     """Average grain size of the profile's material."""
 
+    heat_penetration_number = Hook[float]()
+    """Mean heat penetration number of the profile material."""
+
+    thermal_diffusivity = Hook[float]()
+    """Mean thermal diffusivity of the profile material."""
+
     chemical_composition = Hook[dict[str, float]]()
     """Chemical composition of the profile's material as dict of element symbols to atom fractions (0 to 1)."""
 
@@ -93,19 +100,15 @@ class Profile(HookHost):
     """Phase resp. constituent composition of the profile's material 
     as dict of constituent names to volume fractions (0 to 1)."""
 
+    scale_thickness = Hook[float]()
+    """Thickness of the scale covering the profile."""
+
     def __init__(self, **kwargs):
         """Using the ``__init__`` is not recommended, use one of the factory class methods instead."""
+        self.t = 0
         self.__dict__.update(kwargs)
         super().__init__()
 
-    @classmethod
-    def _base_factory(cls, **kwargs):
-        if "t" not in kwargs:
-            kwargs["t"] = 0
-        return cls(
-            **kwargs
-        )
-
     @classmethod
     def from_groove(
             cls,
@@ -183,19 +186,210 @@ class Profile(HookHost):
 
         polygon = clip_by_rect(poly, -width / 2, -math.inf, width / 2, math.inf)
 
-        return cls._base_factory(
+        return cls(
             cross_section=polygon,
             classifiers=set(groove.classifiers),
             **kwargs
         )
 
+    @classmethod
+    def from_polygon(
+            cls,
+            cross_section: Polygon,
+            classifiers: Set[str],
+            **kwargs
+    ) -> 'Profile':
+        """
+        Creates a custom profile from a shapely polygon object.
+
+        :param cross_section: a polygon representing the cross-section shape
+        :param classifiers: a set of strings classifying the shape
+        :param kwargs: additional keyword arguments to be passed to the Profile constructor
+        """
+
+        if not cross_section.is_simple:
+            raise ValueError("The cross-section must be a simple polygon.")
+
+        if not cross_section.is_valid:
+            raise ValueError("The cross-section must be a valid polygon.")
+
+        if cross_section.is_empty:
+            raise ValueError("The cross-section must not be empty.")
+
+        if len(cross_section.interiors) > 0:
+            raise ValueError("The cross-section must not contain holes.")
+
+        return cls(
+            cross_section=cross_section,
+            classifiers=set(classifiers),
+            **kwargs
+        )
+
     @classmethod
     def round(
             cls,
             radius: Optional[float] = None,
             diameter: Optional[float] = None,
             **kwargs
-    ) -> 'Profile':
+    ) -> 'RoundProfile':
+        """
+        Creates a round shaped profile (a real circle round, without imperfections of round grooves).
+        Give exactly one of ``radius`` and ``diameter``.
+
+        :param radius: the radius of the round profile, must be > 0
+        :param diameter: the diameter of the round profile, must be > 0
+        :param kwargs: additional keyword arguments to be passed to the Profile constructor
+        :raises TypeError: on invalid argument combinations
+        :raises ValueError: if arguments are out of range
+        """
+
+        return RoundProfile(radius, diameter, **kwargs)
+
+    @classmethod
+    def square(
+            cls,
+            side: Optional[float] = None,
+            diagonal: Optional[float] = None,
+            corner_radius: float = 0,
+            **kwargs
+    ) -> 'SquareProfile':
+        """
+        Creates a square shaped profile (a real square with rounded corners, without imperfections of square grooves).
+        A square is oriented to stand on its corner, use :py:meth:`box` to create a side standing one.
+        Give exactly one of ``side`` and ``diagonal``.
+
+        :param side: the side length of the square profile, must be > 0
+        :param diagonal: the diagonal's length of the square profile, must be > 0.
+            Note, that the diagonal is measured at the tips, as if the corner radii were not present
+            for consistency with :py:meth:`box`.
+        :param corner_radius: the radius of the square's corners, must be >= 0 and <= side / 2
+        :param kwargs: additional keyword arguments to be passed to the Profile constructor
+        :raises TypeError: on invalid argument combinations
+        :raises ValueError: if arguments are out of range
+        """
+
+        return SquareProfile(side, diagonal, corner_radius, **kwargs)
+
+    @classmethod
+    def box(
+            cls,
+            height: float,
+            width: float,
+            corner_radius: float = 0,
+            **kwargs
+    ) -> 'BoxProfile':
+        """
+        Creates a box shaped profile (a real rectangular shape with rounded corners,
+        without imperfections of box grooves).
+        A box is oriented to stand on its side, use :py:meth:`square` to create a corner standing square.
+
+        :param height: the height of the box profile, must be > 0
+        :param width: the width of the box profile, must be > 0
+        :param corner_radius: the radius of the square's corners, must be >= 0, <= height / 2 and <= width / 2
+        :param kwargs: additional keyword arguments to be passed to the Profile constructor
+        :raises ValueError: if arguments are out of range
+        """
+
+        return BoxProfile(height, width, corner_radius, **kwargs)
+
+    @classmethod
+    def diamond(
+            cls,
+            height: float,
+            width: float,
+            corner_radius: float = 0,
+            **kwargs
+    ) -> 'DiamondProfile':
+        """
+        Creates a diamond shaped profile (a real diamond shape with rounded corners,
+        without imperfections of diamond grooves).
+        A diamond is oriented to stand on its corner.
+
+        :param height: the height of the diamond profile, must be > 0
+        :param width: the width of the diamond profile, must be > 0
+        :param corner_radius: the radius of the diamond's corners, must be >= 0, <= height / 2 and <= width / 2
+        :param kwargs: additional keyword arguments to be passed to the Profile constructor
+        :raises ValueError: if arguments are out of range
+        """
+
+        return DiamondProfile(height, width, corner_radius, **kwargs)
+
+    def local_height(self, z: float) -> float:
+        coords = np.array([(1, -1), (1, 1)]) * (z, self.height)
+
+        vline = LineString(
+            coords
+        )
+
+        intersection = vline.intersection(self.cross_section)
+
+        return intersection.length
+
+    def local_width(self, y: float) -> float:
+        coords = np.array([(-1, 1), (1, 1)]) * (self.width, y)
+
+        hline = LineString(
+            coords
+        )
+
+        intersection = hline.intersection(self.cross_section)
+
+        return intersection.length
+
+    def fits_material(self, key: str):
+        """Return true, if the given material key is present in the profile's material hook (case-insensitive),
+        otherwise false."""
+
+        def _format(s):
+            try:
+                return s.lower()
+            except AttributeError:
+                raise ValueError(f"Given value {repr(s)} is no str.")
+
+        key = _format(key)
+
+        try:
+            return key in _format(self.material)
+
+        except ValueError:
+            try:
+                return key in {
+                    _format(k)
+                    for k in self.material
+                }
+            except TypeError:
+                raise ValueError("Value of self.material is neither a string or a collection of strings.")
+
+    def plot(self, **kwargs):
+        try:
+            import matplotlib.pyplot as plt
+        except ImportError as e:
+            raise RuntimeError(
+                "This method is only available if matplotlib is installed in the environment. "
+                "You may install it using the 'plot' extra of pyroll-core."
+            ) from e
+
+        fig: plt.Figure = plt.figure(**kwargs)
+        ax: plt.Axes = fig.subplots()
+
+        ax.set_ylabel("y")
+        ax.set_xlabel("z")
+
+        ax.set_aspect("equal", "datalim")
+        ax.grid(lw=0.5)
+
+        ax.plot(*self.cross_section.boundary.xy, color="k")
+        ax.fill(*self.cross_section.boundary.xy, color="k", alpha=0.5)
+        return fig
+
+
+class RoundProfile(Profile):
+    def __init__(
+            self,
+            radius: Optional[float] = None,
+            diameter: Optional[float] = None,
+            **kwargs
+    ):
         """
         Creates a round shaped profile (a real circle round, without imperfections of round grooves).
         Give exactly one of ``radius`` and ``diameter``.
@@ -217,23 +411,149 @@ class Profile(HookHost):
         if radius <= 0:
             raise ValueError("argument value(s) out of range")
 
+        self._radius = radius
+        self._diameter = diameter
+
         center = Point((0, 0))
         circle = center.buffer(radius)
 
-        return cls._base_factory(
+        super().__init__(
             cross_section=circle,
             classifiers={"round"},
             **kwargs
         )
 
-    @classmethod
-    def square(
-            cls,
+    @property
+    def radius(self):
+        """The radius of the round shaped profile (half diameter)."""
+        return self._radius
+
+    @property
+    def diameter(self):
+        """The diameter of the round shaped profile (double radius)."""
+        return self._diameter
+
+    @property
+    def __attrs__(self):
+        return super().__attrs__ | dict(radius=self.radius, diameter=self.diameter)
+
+
+class BoxProfile(Profile):
+    def __init__(
+            self,
+            height: float,
+            width: float,
+            corner_radius: float = 0,
+            **kwargs
+    ):
+        """
+        Creates a box shaped profile (a real rectangular shape with rounded corners,
+        without imperfections of box grooves).
+        A box is oriented to stand on its side, use :py:meth:`square` to create a corner standing square.
+
+        :param height: the height of the box profile, must be > 0
+        :param width: the width of the box profile, must be > 0
+        :param corner_radius: the radius of the square's corners, must be >= 0, <= height / 2 and <= width / 2
+        :param kwargs: additional keyword arguments to be passed to the Profile constructor
+        :raises ValueError: if arguments are out of range
+        """
+
+        if (
+                height <= 0
+                or width <= 0
+                or corner_radius < 0
+                or corner_radius > height / 2
+                or corner_radius > width / 2
+        ):
+            raise ValueError("argument value(s) out of range")
+
+        self._corner_radius = corner_radius
+
+        line = LinearRing(
+            np.array([(1, -1), (1, 1), (-1, 1), (-1, -1)])
+            * (width / 2 - corner_radius, height / 2 - corner_radius)
+        )
+        polygon = Polygon(line)
+        polygon = polygon.buffer(corner_radius)
+
+        super().__init__(
+            cross_section=polygon,
+            classifiers={"box"},
+            **kwargs
+        )
+
+    @property
+    def corner_radius(self):
+        """The radius of the profile's corners resp. edges."""
+        return self._corner_radius
+
+    @property
+    def __attrs__(self):
+        return super().__attrs__ | dict(corner_radius=self._corner_radius)
+
+
+class DiamondProfile(Profile):
+    def __init__(
+            self,
+            height: float,
+            width: float,
+            corner_radius: float = 0,
+            **kwargs
+    ):
+        """
+        Creates a diamond shaped profile (a real diamond shape with rounded corners,
+        without imperfections of diamond grooves).
+        A diamond is oriented to stand on its corner.
+
+        :param height: the height of the diamond profile, must be > 0
+        :param width: the width of the diamond profile, must be > 0
+        :param corner_radius: the radius of the diamond's corners, must be >= 0, <= height / 2 and <= width / 2
+        :param kwargs: additional keyword arguments to be passed to the Profile constructor
+        :raises ValueError: if arguments are out of range
+        """
+
+        if (
+                height <= 0
+                or width <= 0
+                or corner_radius < 0
+                or corner_radius > height / 2
+                or corner_radius > width / 2
+        ):
+            raise ValueError("argument value(s) out of range")
+
+        self._corner_radius = corner_radius
+
+        line = LinearRing(
+            np.array([(1, 0), (0, 1), (-1, 0), (0, -1)])
+            * (width / 2 - corner_radius, height / 2 - corner_radius)
+        )
+        polygon = Polygon(line)
+        polygon = polygon.buffer(corner_radius)
+
+        super().__init__(
+            cross_section=polygon,
+            classifiers={"diamond"},
+            **kwargs
+        )
+
+    @property
+    def corner_radius(self):
+        """The radius of the profile's corners resp. edges."""
+        return self._corner_radius
+
+    @property
+    def __attrs__(self):
+        return super().__attrs__ | dict(corner_radius=self._corner_radius)
+
+
+class SquareProfile(Profile):
+    def __init__(
+            self,
             side: Optional[float] = None,
             diagonal: Optional[float] = None,
             corner_radius: float = 0,
             **kwargs
-    ) -> 'Profile':
+    ):
         """
         Creates a square shaped profile (a real square with rounded corners, without imperfections of square grooves).
         A square is oriented to stand on its corner, use :py:meth:`box` to create a side standing one.
@@ -263,118 +583,39 @@ class Profile(HookHost):
         ):
             raise ValueError("argument value(s) out of range")
 
+        self._side = side
+        self._diagonal = diagonal
+        self._corner_radius = corner_radius
+
         line = LinearRing(np.array([(1, 0), (0, 1), (-1, 0), (0, -1)]) * (diagonal / 2 - corner_radius * np.sqrt(2)))
         polygon = Polygon(line)
         polygon = polygon.buffer(corner_radius)
 
-        return cls._base_factory(
+        super().__init__(
             cross_section=polygon,
             classifiers={"square", "diamond"},
             **kwargs
         )
 
-    @classmethod
-    def box(
-            cls,
-            height: float,
-            width: float,
-            corner_radius: float = 0,
-            **kwargs
-    ) -> 'Profile':
-        """
-        Creates a box shaped profile (a real rectangular shape with rounded corners,
-        without imperfections of box grooves).
-        A box is oriented to stand on its side, use :py:meth:`square` to create a corner standing square.
+    @property
+    def side(self):
+        """The side length of the square profile."""
+        return self._side
 
-        :param height: the height of the box profile, must be > 0
-        :param width: the width of the box profile, must be > 0
-        :param corner_radius: the radius of the square's corners, must be >= 0, <= height / 2 and <= width / 2
-        :param kwargs: additional keyword arguments to be passed to the Profile constructor
-        :raises ValueError: if arguments are out of range
-        """
+    @property
+    def diagonal(self):
+        """The diagonal length of the profile."""
+        return self._diagonal
 
-        if (
-                height <= 0
-                or width <= 0
-                or corner_radius < 0
-                or corner_radius > height / 2
-                or corner_radius > width / 2
-        ):
-            raise ValueError("argument value(s) out of range")
+    @property
+    def corner_radius(self):
+        """The radius of the profile's corners resp. edges."""
+        return self._corner_radius
 
-        line = LinearRing(
-            np.array([(1, -1), (1, 1), (-1, 1), (-1, -1)])
-            * (width / 2 - corner_radius, height / 2 - corner_radius)
+    @property
+    def __attrs__(self):
+        return super().__attrs__ | dict(
+            side=self._side,
+            diagonal=self._diagonal,
+            corner_radius=self._corner_radius
         )
-        polygon = Polygon(line)
-        polygon = polygon.buffer(corner_radius)
-
-        return cls._base_factory(
-            cross_section=polygon,
-            classifiers={"box"},
-            **kwargs
-        )
-
-    @classmethod
-    def diamond(
-            cls,
-            height: float,
-            width: float,
-            corner_radius: float = 0,
-            **kwargs
-    ) -> 'Profile':
-        """
-        Creates a diamond shaped profile (a real diamond shape with rounded corners,
-        without imperfections of diamond grooves).
-        A diamond is oriented to stand on its corner.
-
-        :param height: the height of the diamond profile, must be > 0
-        :param width: the width of the diamond profile, must be > 0
-        :param corner_radius: the radius of the diamonds's corners, must be >= 0, <= height / 2 and <= width / 2
-        :param kwargs: additional keyword arguments to be passed to the Profile constructor
-        :raises ValueError: if arguments are out of range
-        """
-
-        if (
-                height <= 0
-                or width <= 0
-                or corner_radius < 0
-                or corner_radius > height / 2
-                or corner_radius > width / 2
-        ):
-            raise ValueError("argument value(s) out of range")
-
-        line = LinearRing(
-            np.array([(1, 0), (0, 1), (-1, 0), (0, -1)])
-            * (width / 2 - corner_radius, height / 2 - corner_radius)
-        )
-        polygon = Polygon(line)
-        polygon = polygon.buffer(corner_radius)
-
-        return cls._base_factory(
-            cross_section=polygon,
-            classifiers={"diamond"},
-            **kwargs
-        )
-
-    def local_height(self, z: float) -> float:
-        coords = np.array([(1, -1), (1, 1)]) * (z, self.height)
-
-        vline = LineString(
-            coords
-        )
-
-        intersection = vline.intersection(self.cross_section)
-
-        return intersection.length
-
-    def local_width(self, y: float) -> float:
-        coords = np.array([(-1, 1), (1, 1)]) * (self.width, y)
-
-        hline = LineString(
-            coords
-        )
-
-        intersection = hline.intersection(self.cross_section)
-
-        return intersection.length
