@@ -1,7 +1,7 @@
-from typing import Iterable, Union
+from typing import Union, Set
 
 import numpy as np
-from scipy.interpolate import RegularGridInterpolator, interpn
+from scipy.interpolate import interpn
 from shapely.geometry import LineString
 
 from ..grooves import GrooveBase
@@ -50,6 +50,9 @@ class Roll(HookHost):
     temperature = Hook[float]()
     """Mean temperature."""
 
+    core_temperature = Hook[float]()
+    """Effective core temperature."""
+
     surface_temperature = Hook[float]()
     """Effective surface temperature."""
 
@@ -71,7 +74,7 @@ class Roll(HookHost):
     density = Hook[float]()
     """Density (specific weight) of the roll material."""
 
-    material = Hook[Union[str, Iterable[str]]]()
+    material = Hook[Union[str, Set[str]]]()
     """String or sequence of strings classifying the material of the roll.
     Can be used by material databases to retrieve respective data."""
 
@@ -90,9 +93,27 @@ class Roll(HookHost):
     where ``n = len(self.surface_x)`` and ``m = len(self.surface_z)``.
     """
 
+    heat_penetration_number = Hook[float]()
+    """Mean heat penetration number of the roll material."""
+
+    thermal_diffusivity = Hook[float]()
+    """Mean thermal diffusivity of the roll material."""
+
     neutral_point = Hook[float]()
     """Point at the roll surface where the shear stress is zero."""
 
+    thermal_stress = Hook[float]()
+    """Thermal stress inside the roll body."""
+
+    centrifugal_force_stress = Hook[float]()
+    """Centrifugal stress inside the roll body."""
+
+    mounting_stress = Hook[float]()
+    """Stress inside the roll body caused by the roll mounting system."""
+
+    ultimate_tensile_strength = Hook[float]()
+    """Ultimate Tensile strength of the roll material."""
+
     def __init__(
             self,
             groove: GrooveBase,
