@@ -54,10 +54,25 @@ def filling_ratio(self: RollPass.OutProfile):
     return self.width / self.roll_pass.usable_width
 
 
+@RollPass.OutProfile.cross_section_filling_ratio
+def cross_section_filling_ratio(self: RollPass.OutProfile):
+    return self.cross_section.area / self.roll_pass.usable_cross_section.area
+
+
+@RollPass.OutProfile.filling_error
+def filling_error(self: RollPass.OutProfile):
+    return self.width / self.roll_pass.target_width - 1
+
+
+@RollPass.OutProfile.cross_section_error
+def cross_section_error(self: RollPass.OutProfile):
+    return self.cross_section.area / self.roll_pass.target_cross_section_area - 1
+
+
 @RollPass.OutProfile.cross_section
 def cross_section(self: RollPass.OutProfile) -> Polygon:
     cs = helpers.out_cross_section(self.roll_pass, self.width)
-    if cs.width < self.width:
+    if cs.width * 1.01 < self.width:
         raise ValueError(
             "Profile's width can not be larger than its contour lines."
             "May be caused by critical overfilling."
@@ -68,7 +83,7 @@ def cross_section(self: RollPass.OutProfile) -> Polygon:
 @ThreeRollPass.OutProfile.cross_section
 def cross_section3(self: ThreeRollPass.OutProfile) -> Polygon:
     cs = helpers.out_cross_section3(self.roll_pass, self.width)
-    if (cs.bounds[3] - cs.centroid.y) * 2 < self.width:
+    if (cs.bounds[3] - cs.centroid.y) * 2.02 < self.width:
         raise ValueError(
             "Profile's width can not be larger than its contour lines."
             "May be caused by critical overfilling."
