@@ -3,7 +3,7 @@ from typing import List, Union, cast
 
 import numpy as np
 from shapely.affinity import translate, rotate
-from shapely.geometry import LineString, Polygon
+from shapely.geometry import LineString, Polygon, MultiPolygon
 
 from ..disk_elements import DiskElementUnit
 from ..hooks import Hook
@@ -44,6 +44,12 @@ class RollPass(DiskElementUnit, DeformationUnit):
     tip_cross_section = Hook[Polygon]()
     """Cross-section of the roll pass at filling with its tip width."""
 
+    reappearing_cross_section = Hook[MultiPolygon]()
+    """Cross-section of the roll pass witch appears again in the next roll-pass due to spreading."""
+
+    displaced_cross_section = Hook[MultiPolygon]()
+    """Cross-section of the roll pass witch is displaced due to elongation and won't reappear in the next roll-pass."""
+
     roll_force = Hook[float]()
     """Vertical roll force."""
 
@@ -53,6 +59,21 @@ class RollPass(DiskElementUnit, DeformationUnit):
     back_tension = Hook[float]()
     """Back tension acting on the current roll pass."""
 
+    elongation_efficiency = Hook[float]()
+    """Efficiency of a roll pass to elongate a incoming profile."""
+
+    target_width = Hook[float]()
+    """Target width of the out profile."""
+
+    target_filling_ratio = Hook[float]()
+    """Target filling ratio of the out profile."""
+
+    target_cross_section_area = Hook[float]()
+    """Target cross-section of the out profile."""
+
+    target_cross_section_filling_ratio = Hook[float]()
+    """Target cross-section filling ratio of the out profile."""
+
     def __init__(
             self,
             roll: BaseRoll,
@@ -107,6 +128,7 @@ class RollPass(DiskElementUnit, DeformationUnit):
             in_profile = rotator.out_profile
 
         super().init_solve(in_profile)
+        self.out_profile.cross_section = self.usable_cross_section
 
     def get_root_hook_results(self):
         super_results = super().get_root_hook_results()
@@ -134,6 +156,16 @@ class RollPass(DiskElementUnit, DeformationUnit):
         """Represents an outgoing profile of a roll pass."""
 
         filling_ratio = Hook[float]()
+        """Ratio of profile width to usable width of the groove as width based measure of ideal filling."""
+
+        cross_section_filling_ratio = Hook[float]()
+        """Ratio of profile cross-section to usable cross-section of the pass as cross-section based measure of ideal filling."""
+
+        filling_error = Hook[float]()
+        """Ratio of profile width to target width as width based measure of target filling."""
+
+        cross_section_error = Hook[float]()
+        """Ratio of profile cross-section to target cross-section as cross-section based measure of target filling."""
 
     class Roll(BaseRoll):
         """Represents a roll applied in a :py:class:`RollPass`."""
@@ -178,3 +210,51 @@ class RollPass(DiskElementUnit, DeformationUnit):
 
         class OutProfile(Profile, DiskElementUnit.DiskElement.OutProfile, DeformationUnit.OutProfile):
             """Represents an outgoing profile of a disk element unit."""
+
+    def plot(self, **kwargs):
+        try:
+            import matplotlib.pyplot as plt
+        except ImportError as e:
+            raise RuntimeError(
+                "This method is only available if matplotlib is installed in the environment. "
+                "You may install it using the 'plot' extra of pyroll-core."
+            ) from e
+
+        fig: plt.Figure = plt.figure(**kwargs)
+        ax: plt.Axes
+        axl: plt.Axes
+        ax, axl = fig.subplots(nrows=2, height_ratios=[1, 0.3])
+
+        if self.label:
+            ax.set_title(f"Roll Pass '{self.label}'")
+
+        ax.set_ylabel("y")
+        ax.set_xlabel("z")
+
+        ax.set_aspect("equal", "datalim")
+        ax.grid(lw=0.5)
+
+        c = []
+        ipp = []
+        ipr = []
+        opp = []
+        opr = []
+
+        for cl in self.contour_lines:
+            c = ax.plot(*cl.xy, color="k", label="roll surface")
+
+        if self.in_profile:
+            ipp = ax.fill(*self.in_profile.cross_section.boundary.xy, alpha=0.5, color="red", label="in profile")
+            ipr = ax.fill(*self.in_profile.equivalent_rectangle.boundary.xy, fill=False, color="red", ls="--",
+                          label="in eq. rectangle")
+
+        if self.out_profile:
+            opp = ax.fill(*self.out_profile.cross_section.boundary.xy, alpha=0.5, color="blue", label="out profile")
+            opr = ax.fill(*self.out_profile.equivalent_rectangle.boundary.xy, fill=False, color="blue", ls="--",
+                          label="out eq. rectangle")
+
+        axl.axis("off")
+        axl.legend(handles=c + ipp + opp + ipr + opr, ncols=2, loc="lower center")
+        fig.set_layout_engine('constrained')
+
+        return fig
