@@ -12,8 +12,17 @@ class PassSequence(Unit, Sequence[Unit]):
     Can be nested to define distinct rolling lines or similar.
     """
 
-    total_elongation = Hook[float]()
-    """Total elongation of the workpiece within the sequence."""
+    elongation = Hook[float]()
+    """Coefficient of elongation (change in length)."""
+
+    log_elongation = Hook[float]()
+    """Log. coefficient of elongation (change in length)."""
+
+    abs_elongation = Hook[float]()
+    """Absolute elongation (change in length)."""
+
+    rel_elongation = Hook[float]()
+    """Relative elongation (change in length)."""
 
     def __init__(self, units: Sequence[Unit], label: str = "", **kwargs):
         """
@@ -40,6 +49,10 @@ class PassSequence(Unit, Sequence[Unit]):
     class OutProfile(Profile, Unit.OutProfile):
         """Represents an outgoing profile of a pass sequence unit."""
 
+        def root_hook_fallback(self, hook):
+            """Copy the value from the in profile as fallback for root hooks."""
+            return getattr(self.unit.units[-1].out_profile, hook.name, None)
+
     def __len__(self) -> int:
         return self._subunits.__len__()
 
