@@ -33,6 +33,18 @@ class Unit(HookHost):
     surface_area = Hook[float]()
     """Surface area of workpiece within the unit."""
 
+    volume_flux = Hook[float]()
+    """Flux/throughput of volume through this unit."""
+
+    mass_flux = Hook[float]()
+    """Flux/throughput of mass through this unit."""
+
+    power = Hook[float]()
+    """Total energy demand per time of this unit."""
+
+    energy_consumption = Hook[float]()
+    """Energy consumption of this unit per produced mass."""
+
     def __init__(self, label: str = "", parent=None, **kwargs):
         super().__init__()
         self.label = label
@@ -71,6 +83,20 @@ class Unit(HookHost):
             raise IndexError("This unit has no previous, as it is the first one.")
         return self.parent.subunits[i - 1]
 
+    def prev_of(self, unit_type: type):
+        """
+        Returns the instance of the first predecessor of the given type in the sequence.
+        Like the :py:attr:`Unit.prev` property, but returns the first unit with given type.
+
+        :raises ValueError: if this unit has no parent unit
+        """
+        prev = self.prev
+
+        while True:
+            if isinstance(prev, unit_type):
+                return prev
+            prev = prev.prev
+
     @property
     def next(self):
         """
@@ -85,6 +111,20 @@ class Unit(HookHost):
             raise IndexError("This unit has no next, as it is the last one.")
         return self.parent.subunits[i + 1]
 
+    def next_of(self, unit_type: type):
+        """
+        Returns the instance of the first predecessor of the given type in the sequence.
+        Like the :py:attr:`Unit.prev` property, but returns the first unit with given type.
+
+        :raises ValueError: if this unit has no parent unit
+        """
+        next_ = self.next
+
+        while True:
+            if isinstance(next_, unit_type):
+                return next_
+            next_ = next_.next
+
     def init_solve(self, in_profile: BaseProfile):
         """
         Method called by the standard :py:meth:`solve` implementation to init
@@ -193,8 +233,8 @@ class Unit(HookHost):
                 e for e in template.__dict__.items()
                 if not e[0].startswith("_")
             )
-            super().__init__(**kwargs)
             self._unit = weakref.ref(unit)
+            super().__init__(**kwargs)
 
         @property
         def unit(self) -> 'Unit':
@@ -207,6 +247,10 @@ class Unit(HookHost):
     class OutProfile(Profile):
         """Represents an outgoing profile of a unit."""
 
+        def root_hook_fallback(self, hook):
+            """Copy the value from the in profile as fallback for root hooks."""
+            return getattr(self.unit.in_profile, hook.name, None)
+
     class _SubUnitsList(list):
         """Specialized list for holding the units of a pass sequence."""
 
